CompositionInterfaceMechanism
=============================

.. container:: related

    *Related*

    .. toctree::
       :maxdepth: 1

       Mechanism
       Composition

.. automodule:: psyneulink.core.components.mechanisms.processing.compositioninterfacemechanism
   :members:
   :private-members:
   :exclude-members: random
